package betterquesting.questing.party;

import betterquesting.api.enums.EnumPartyStatus;
import betterquesting.api.properties.NativeProps;
import betterquesting.api.questing.party.IParty;
import betterquesting.api.questing.party.IPartyDatabase;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.storage.SimpleDatabase;
import betterquesting.storage.QuestSettings;
import java.util.HashMap;
import java.util.List;
import java.util.UUID;
import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;

/* loaded from: betterquesting_questing_party.jar:betterquesting/questing/party/PartyManager.class */
public class PartyManager extends SimpleDatabase<IParty> implements IPartyDatabase {
    public static final PartyManager INSTANCE = new PartyManager();
    private final HashMap<UUID, Integer> partyCache = new HashMap<>();

    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, @Nullable List list) {
        return writeToNBT((NBTTagList) nBTBase, (List<Integer>) list);
    }

    public synchronized IParty createNew(int id) {
        IParty party = new PartyInstance();
        if (id >= 0) {
            add(id, party);
        }
        return party;
    }

    @Nullable
    public synchronized DBEntry<IParty> getParty(@Nonnull UUID uuid) {
        if (!((Boolean) QuestSettings.INSTANCE.getProperty(NativeProps.PARTY_ENABLE)).booleanValue()) {
            return null;
        }
        Integer cachedID = this.partyCache.get(uuid);
        IParty cachedParty = cachedID == null ? null : (IParty) getValue(cachedID.intValue());
        if (cachedID != null && cachedParty == null) {
            this.partyCache.remove(uuid);
        } else if (cachedParty != null) {
            EnumPartyStatus status = cachedParty.getStatus(uuid);
            if (status != null) {
                return new DBEntry<>(cachedID.intValue(), cachedParty);
            }
            this.partyCache.remove(uuid);
        }
        for (DBEntry<IParty> entry : getEntries()) {
            EnumPartyStatus status2 = ((IParty) entry.getValue()).getStatus(uuid);
            if (status2 != null) {
                this.partyCache.put(uuid, Integer.valueOf(entry.getID()));
                return entry;
            }
        }
        return null;
    }

    public NBTTagList writeToNBT(NBTTagList json, @Nullable List<Integer> subset) {
        for (DBEntry<IParty> entry : getEntries()) {
            if (subset == null || subset.contains(Integer.valueOf(entry.getID()))) {
                NBTTagCompound jp = ((IParty) entry.getValue()).writeToNBT(new NBTTagCompound());
                jp.func_74768_a("partyID", entry.getID());
                json.func_74742_a(jp);
            }
        }
        return json;
    }

    public void readFromNBT(NBTTagList json, boolean merge) {
        if (!merge) {
            reset();
        }
        for (int i = 0; i < json.func_74745_c(); i++) {
            NBTTagCompound jp = json.func_150305_b(i);
            int partyID = jp.func_150297_b("partyID", 99) ? jp.func_74762_e("partyID") : -1;
            if (partyID >= 0) {
                IParty party = new PartyInstance();
                party.readFromNBT(jp);
                if (party.getMembers().size() > 0) {
                    add(partyID, party);
                }
            }
        }
    }

    public synchronized void reset() {
        super.reset();
        this.partyCache.clear();
    }
}
